@@ -449,9 +449,9 @@ class MyWhatify:
         return datasets[['creation_date', 'id', 'name', 'problem_type', 'row_count', 'state']]
 
     @classmethod
-    def get_tasks(cls, data_name):
+    def get_tasks(cls, data_name, filters=None):
         logging.info('getting the Tasks list for data_name: ' + str(data_name))
-        return my_toolkit.Task.list(search_term=data_name)['hits']
+        return my_toolkit.Task.list(search_term=data_name, filter_=filters)['hits']
 
     @classmethod
     def get_tasks_list(cls, len=10, search_term=None):
